#
# spec file for package python-tlslite
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.
#
# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           python-tlslite
Version:        0.4.6
Release:        3.2
License:        BSD-3-Clause
Summary:        A Python Library That Implements SSL 3.0, TLS 1.0, and TLS 1.1
Url:            http://trevp.net/tlslite/
Group:          Development/Libraries/Python
Source:         http://pypi.python.org/packages/source/t/tlslite/tlslite-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
TLS Lite is a free python library that implements SSL 3.0, TLS 1.0, and TLS
1.1. TLS Lite supports non-traditional authentication methods such as SRP,
shared keys, and cryptoIDs in addition to X.509 certificates. TLS Lite is pure
Python, however it can access OpenSSL, cryptlib, pycrypto, and GMPY for faster
crypto operations. TLS Lite integrates with httplib, xmlrpclib, poplib,
imaplib, smtplib, SocketServer, asyncore, and Twisted.

%package doc
Summary:        Documentation for python-tlslite
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}

%description doc
TLS Lite is a free python library that implements SSL 3.0, TLS 1.0, and TLS
1.1. TLS Lite supports non-traditional authentication methods such as SRP,
shared keys, and cryptoIDs in addition to X.509 certificates. TLS Lite is pure
Python, however it can access OpenSSL, cryptlib, pycrypto, and GMPY for faster
crypto operations. TLS Lite integrates with httplib, xmlrpclib, poplib,
imaplib, smtplib, SocketServer, asyncore, and Twisted.

This package contains documentation.

%prep
%setup -q -n tlslite-%{version}

%build
python setup.py build
# Fix perms
find . -type f | xargs chmod 0644

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
%fdupes %{buildroot}

%files
%defattr(-,root,root,-)
%doc LICENSE README
%{python_sitelib}/*
%{_bindir}/tls.py
%{_bindir}/tlsdb.py


%files doc
%defattr(-,root,root)
%doc docs

%changelog
* Sun Nov 17 2013 p.drouand@gmail.com
- Update to version 0.4.6
  + **API CHANGE**: TLSClosedConnectionError instead of ValueError when writing
    to a closed connection.  This inherits from socket.error, so should
    interact better with SocketServer (see http://bugs.python.org/issue14574)
    and other things expecting a socket.error in this situation.
  + Added support for RC4-MD5 ciphersuite (if enabled in settings)
    This is allegedly necessary to connect to some Internet servers.
  + Added TLSConnection.unread() function
  + Switched to New-style classes (inherit from 'object')
  + Minor cleanups
- Changes from 0.4.5
  + release engineering problem, skipped!
- Changes from 0.4.4
  + Added Python 3 support
  + Added NPN client support
  + Switched to RC4 as preferred cipher
    faster in Python, avoids "Lucky 13" timing attacks
  + Fixed bug when specifying ciphers for anon ciphersuites
  + Made RSA hashAndVerify() tolerant of sigs w/o encoded NULL AlgorithmParam
    (this function is not used for TLS currently, and this tolerance may
    not even be necessary)
- Remove useless CFLAGS definition
- Remove redundant %%clean section
* Tue Nov 13 2012 jfunk@funktronics.ca
- Update to 0.4.3:
  * Minor bugfix (0.4.2 doesn't load tackpy)
- 0.4.2 - 9/25/2012
  * Updated TACK (compatible with tackpy 0.9.9)
* Wed May 23 2012 jfunk@funktronics.ca
- Update to 0.4.1
  * Fixed RSA padding bugs (w/help from John Randolph)
  * Updated TACK (compatible with tackpy 0.9.7)
  * Added SNI
  * Added NPN server support (Sam Rushing/Google)
  * Added AnonDH (Dimitris Moraitis)
  * Added X509CertChain.parsePemList
  * Improved XML-RPC (Kees Bos)
* Mon Feb 13 2012 jfunk@funktronics.ca
- Update spec to reflect current conventions
- Update to 0.4.0:
  - Fixed pycrypto support
  - Fixed python 2.6 problems
- 0.3.9.x - 2/7/2012
  - Much code cleanup, in particular decomposing the handshake functions so
    they are readable.  The main new feature is support for Convergence TACK,
    an experimental authentication method that provides a new way to pin
    server certificates (See https://github.com/moxie0/Convergence/wiki/TACK ).
  - Security Fixes
  - Sends SCSV ciphersuite as per RFC 5746, to signal non-renegotiated
    Client Hello.  Does not support renegotiation (never has).
  - Change from e=3 to e=65537 for generated RSA keys, not strictly
    necessary but mitigates risk of sloppy verifier.
  - 1/(n-1) countermeasure for BEAST.
  - Behavior changes:
  - Split cmdline into tls.py and tlstest.py, improved options.
  - Formalized LICENSE.
  - Defaults to closing socket after sending close_notify, fixes hanging.
    problem that would occur sometime when waiting for other party's
    close_notify.
  - Update SRP to RFC 5054 compliance.
  - Removed client handshake "callbacks", no longer support the SRP
    re-handshake idiom within a single handshake function.
  - Bugfixes
  - Added hashlib support, removes Deprecation Warning due to sha and md5.
  - Handled GeneratorExit exceptions that are a new Python feature, and
    interfere with the async code if not handled.
  - Removed:
  - Shared keys (it was based on an ancient I-D, not TLS-PSK).
  - cryptlib support, it wasn't used much, we have enough other options.
  - cryptoIDs (Convergence TACK is better).
  - win32prng extension module, as os.urandom is now available.
  - Twisted integration (unused?, slowed down loading).
  - Jython code (ancient, didn't work).
  - Compat support for python versions < 2.7.
  - Additions
  - Support for Convergence TACK via TACKpy.
  - Support for CertificateRequest.certificate_authorities ("reqCAs")
  - Added TLSConnection.shutdown() to better mimic socket.
  - Enabled Session resumption for XMLRPCTransport.
* Fri Feb 19 2010 jfunk@funktronics.ca
- Use --record-rpm
- Build as noarch
- Split off doc package
* Wed Aug 23 2006 James Oakley <jfunk@funktronics.ca> - 0.3.8-3
- Set prefix
* Tue Jul 25 2006 James Oakley <jfunk@funktronics.ca> - 0.3.8-2
- Build under build service
* Thu Dec  1 2005 James Oakley <jfunk@funktronics.ca> - 0.3.8-1
- Initial release
